@@ -5,8 +5,9 @@ def CorrMatrixAnalysis(df, dep_feature):
             Displays in depth analysis of the correlation between features. Currently only addresses
             correlation of dependent feature to independent features, but will be updated soon.
         params (see default values for examples):
-            df          - The dataframe to analyze.
+            df          - The dataframe to analyze
             dep_feature - The dependent feature
+            output      - Whether or not to return the organized list of correlated features
         example call:
             df = pd.read_csv('Iris.csv')
             CorrMatrixAnalysis(df, 'species')'''
@@ -22,4 +23,6 @@ def CorrMatrixAnalysis(df, dep_feature):
         if corr_[1].size > 0:
             print("Features With " + corr_[0] + " Correlation to " + dep_feature + ":")
             [print("% .2f  -" % round(dep[x],2), x) for x in corr_[1].index]
-            print('\n')
\ No newline at end of file
+            print('\n')
+    if output:
+      return corrs
\ No newline at end of file
